==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/VirtualGatewaySpecLoggingAccessLogFileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecLoggingAccessLogFileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property format The specified format for the logs.
 * @property path File path to write access logs to. You can use `/dev/stdout` to send access logs to standard out. Must be between 1 and 255 characters in length.
 */
public data class VirtualGatewaySpecLoggingAccessLogFileArgs(
    public val format: Output<VirtualGatewaySpecLoggingAccessLogFileFormatArgs>? = null,
    public val path: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecLoggingAccessLogFileArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecLoggingAccessLogFileArgs =
        com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecLoggingAccessLogFileArgs.builder()
            .format(format?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .path(path.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualGatewaySpecLoggingAccessLogFileArgs].
 */
@PulumiTagMarker
public class VirtualGatewaySpecLoggingAccessLogFileArgsBuilder internal constructor() {
    private var format: Output<VirtualGatewaySpecLoggingAccessLogFileFormatArgs>? = null

    private var path: Output<String>? = null

    /**
     * @param value The specified format for the logs.
     */
    @JvmName("kjiusetscuitgbmc")
    public suspend fun format(`value`: Output<VirtualGatewaySpecLoggingAccessLogFileFormatArgs>) {
        this.format = value
    }

    /**
     * @param value File path to write access logs to. You can use `/dev/stdout` to send access logs to standard out. Must be between 1 and 255 characters in length.
     */
    @JvmName("lmwhipupalswlguj")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value The specified format for the logs.
     */
    @JvmName("irfiqsnirrxmkdca")
    public suspend fun format(`value`: VirtualGatewaySpecLoggingAccessLogFileFormatArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.format = mapped
    }

    /**
     * @param argument The specified format for the logs.
     */
    @JvmName("rbsyuslkfsonnpoj")
    public suspend
    fun format(argument: suspend VirtualGatewaySpecLoggingAccessLogFileFormatArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualGatewaySpecLoggingAccessLogFileFormatArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.format = mapped
    }

    /**
     * @param value File path to write access logs to. You can use `/dev/stdout` to send access logs to standard out. Must be between 1 and 255 characters in length.
     */
    @JvmName("jeeaivcccbssopuy")
    public suspend fun path(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.path = mapped
    }

    internal fun build(): VirtualGatewaySpecLoggingAccessLogFileArgs =
        VirtualGatewaySpecLoggingAccessLogFileArgs(
            format = format,
            path = path ?: throw PulumiNullFieldException("path"),
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appmesh/kotlin/inputs/VirtualGatewaySpecLoggingAccessLogFileArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appmesh.kotlin.inputs

import com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecLoggingAccessLogFileArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property format The specified format for the logs.
 * @property path File path to write access logs to. You can use `/dev/stdout` to send access logs to standard out. Must be between 1 and 255 characters in length.
 */
public data class VirtualGatewaySpecLoggingAccessLogFileArgs(
    public val format: Output<VirtualGatewaySpecLoggingAccessLogFileFormatArgs>? = null,
    public val path: Output<String>,
) : ConvertibleToJava<com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecLoggingAccessLogFileArgs> {
    override fun toJava(): com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecLoggingAccessLogFileArgs =
        com.pulumi.aws.appmesh.inputs.VirtualGatewaySpecLoggingAccessLogFileArgs.builder()
            .format(format?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .path(path.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [VirtualGatewaySpecLoggingAccessLogFileArgs].
 */
@PulumiTagMarker
public class VirtualGatewaySpecLoggingAccessLogFileArgsBuilder internal constructor() {
    private var format: Output<VirtualGatewaySpecLoggingAccessLogFileFormatArgs>? = null

    private var path: Output<String>? = null

    /**
     * @param value The specified format for the logs.
     */
    @JvmName("ftwsasohvykhpnng")
    public suspend fun format(`value`: Output<VirtualGatewaySpecLoggingAccessLogFileFormatArgs>) {
        this.format = value
    }

    /**
     * @param value File path to write access logs to. You can use `/dev/stdout` to send access logs to standard out. Must be between 1 and 255 characters in length.
     */
    @JvmName("eaagbdijofnngofc")
    public suspend fun path(`value`: Output<String>) {
        this.path = value
    }

    /**
     * @param value The specified format for the logs.
     */
    @JvmName("iedtrrfcqyfgyxva")
    public suspend fun format(`value`: VirtualGatewaySpecLoggingAccessLogFileFormatArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.format = mapped
    }

    /**
     * @param argument The specified format for the logs.
     */
    @JvmName("qbkbqnkdjvqgetru")
    public suspend fun format(argument: suspend VirtualGatewaySpecLoggingAccessLogFileFormatArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualGatewaySpecLoggingAccessLogFileFormatArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.format = mapped
    }

    /**
     * @param value File path to write access logs to. You can use `/dev/stdout` to send access logs to standard out. Must be between 1 and 255 characters in length.
     */
    @JvmName("hmhudqamjcvrlkdn")
    public suspend fun path(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.path = mapped
    }

    internal fun build(): VirtualGatewaySpecLoggingAccessLogFileArgs =
        VirtualGatewaySpecLoggingAccessLogFileArgs(
            format = format,
            path = path ?: throw PulumiNullFieldException("path"),
        )
}
